Iroh supports multiple protocols, and we do need multiple protocols, lets say one for proxying
TCP connection, another for proxying HTTP connection, and so on. But if we use different APNS
to handle them, we will end up creating more connections than minimally required (one connection
can only talk one APNS). So, we use a single APNS for all the protocols, and we use the first
line of the input to determine the protocol.