pub type IDMap = Arc<Mutex<Vec<(String, (u16, Endpoint))>>>;Expand description
IDMap stores the fastn port and the endpoint for every identity
why is it a Vec and not a HasMap? the incoming requests contain the first few characters of id
and not the full id. the reason for this is we want to use
since the number of identities will be small, a prefix match is probably going to be the same speed as the hash map exact lookup.
Aliased Type
pub struct IDMap { /* private fields */ }